module.exports = defineTest({
	description: 'handles default function with id exports wrapped in parens'
});
